@@ -157,13 +157,25 @@ if (!array_key_exists($page, $allowed_pages)) {
                 
                 <!-- User Dropdown -->
                 <div class="navbar-nav ms-auto">
-                    <!-- Font Size Toggle -->
-                    <button class="font-size-toggle me-3<?php echo (isset($_SESSION['large_fonts']) && $_SESSION['large_fonts']) ? ' active' : ''; ?>" 
-                            id="fontSizeToggle" 
-                            title="Toggle larger fonts">
-                        <i class="fa fa-font"></i>
-                        <span class="d-none d-sm-inline">Aa</span>
-                    </button>
+                    <!-- Font Size Toggle Switch -->
+                    <div class="font-size-toggle-wrapper">
+                        <label class="font-size-toggle-label" for="fontSizeToggle">
+                            <span class="font-size-icons">
+                                <span class="font-size-small">A</span>
+                                <span class="font-size-large">A</span>
+                            </span>
+                            <div class="toggle-switch" title="Toggle larger font size for better readability">
+                                <input type="checkbox" 
+                                       id="fontSizeToggle" 
+                                       <?php echo (isset($_SESSION['large_fonts']) && $_SESSION['large_fonts']) ? 'checked' : ''; ?>
+                                       aria-label="Toggle larger font size"
+                                       aria-describedby="fontSizeDescription"
+                                       role="switch">
+                                <span class="toggle-slider"></span>
+                            </div>
+                            <span class="visually-hidden" id="fontSizeDescription">Toggle between normal and large font sizes for better readability</span>
+                        </label>
+                    </div>
                     
                     <span class="navbar-text text-light me-3">
                         Welcome, <?php 
@@ -388,23 +400,35 @@ if (!array_key_exists($page, $allowed_pages)) {
         document.addEventListener('DOMContentLoaded', function() {
             const fontToggle = document.getElementById('fontSizeToggle');
             if (fontToggle) {
-                fontToggle.addEventListener('click', function() {
-                    // Send AJAX request to toggle font size
+                fontToggle.addEventListener('change', function() {
+                    const isChecked = this.checked;
+                    
+                    // Send AJAX request to set font size preference
                     fetch('api/font-size-toggle.php', {
                         method: 'POST',
                         headers: {
                             'Content-Type': 'application/x-www-form-urlencoded',
                             'X-CSRF-Token': '<?php echo get_csrf_token(); ?>'
                         },
-                        body: 'action=toggle'
+                        body: 'action=set&value=' + (isChecked ? '1' : '0')
                     })
                     .then(response => response.json())
                     .then(data => {
                         if (data.success) {
-                            // Toggle the class on body
+                            // Toggle the class on body based on the response
                             document.body.classList.toggle('large-fonts', data.large_fonts);
-                            // Toggle active state on button
-                            fontToggle.classList.toggle('active', data.large_fonts);
+                            
+                            // Update aria-pressed for screen readers
+                            fontToggle.setAttribute('aria-checked', data.large_fonts ? 'true' : 'false');
+                            
+                            // Announce change to screen readers
+                            const announcement = document.createElement('div');
+                            announcement.setAttribute('role', 'status');
+                            announcement.setAttribute('aria-live', 'polite');
+                            announcement.className = 'visually-hidden';
+                            announcement.textContent = data.large_fonts ? 'Large font size enabled' : 'Normal font size enabled';
+                            document.body.appendChild(announcement);
+                            setTimeout(() => announcement.remove(), 1000);
                         }
                     })
                     .catch(error => console.error('Error toggling font size:', error));
